;
; Combined EOFs
;***********************************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl" 

begin
   neof	=  4
   latS	= -10.
   latN	= 40.
   lonW	= 40.
   lonE	= 160. 

;-------- read in data (olr and u850) ----------
   f	= addfile ("ERAI.OLR_rmv.19860101-20161231.30S-60N.May-Oct.day.mean.nc", "r") 
   olr	= f->OLR_rmv(:,{latS:latN},{lonW:lonE})
   printVarSummary(olr)

   time	= olr&time
;   date	= cd_calendar(time,-2)
;   print(date)
;exit

  f	= addfile ("ERAI.U850_rmv.19860101-20161231.30S-60N.May-Oct.day.mean.nc", "r") 
  u850	= f->U850_rmv(:,{latS:latN},{lonW:lonE})
  printVarSummary(u850)
 
   dims	= dimsizes( olr )
   ntim	= dims(0)
   nlat	= dims(1)
   mlon	= dims(2)

;---------- the two anomaly fields were each normalized by their area averaged temporal standard deviation over the ASM region ----
   lon	= olr&lon

   var_olr	= dim_variance_n_Wrap(olr,0)
   var_u850	= dim_variance_n_Wrap(u850,0)
   printVarSummary(var_olr)

   avg_olr   = wgt_areaave_Wrap(var_olr,1.0,1.0,1)
   avg_u850  = wgt_areaave_Wrap(var_u850,1.0,1.0,1)  

 printVarSummary(avg_olr)
 printVarSummary(avg_u850)
 print(avg_olr)
 print(avg_u850)
 
;   do i=0,20
;      do j=0,48
;         do k=0,5519
;            olr(k,i,j)=olr(k,i,j)/sqrt(zavg_olr(i,j))
;            u850(k,i,j)=u850(k,i,j)/sqrt(zavg_u850(i,j))
;         end do
;      end do
;   end do

    olr=olr/sqrt(avg_olr)
    u850=u850/sqrt(avg_u850)

;-------------- Combine the two normalized data into one variable ----------
  cdata = new ( (/nlat,2*mlon,ntim/), typeof(olr), getFillValue(olr))
  do n1 = 0,nlat-1
     do ml = 0,mlon-1
        cdata(n1,ml       ,:) = (/  olr(:,n1,ml) /)
        cdata(n1,ml+  mlon,:) = (/ u850(:,n1,ml) /)
     end do
  end do

;------------- Compute **combined** EOF; Sign of EOF is arbitrary ----------
  eof_cdata	= eofunc_Wrap(cdata   , neof, False)      ; (neof,lat,2*mlon)
  
  delete(eof_cdata!0)
  eof_cdata!0	= "eof"
  eof_cdata!1	= "lat"
  eof_cdata!2	= "lon"
  eof_cdata&lat	= olr&lat
;  eof_cdata&lon= olr&lon

  print("==============")
  printVarSummary(eof_cdata)
  printMinMax(eof_cdata, True)

  eof_ts_cdata = eofunc_ts_Wrap(cdata,eof_cdata,False)   ; (neof,2*ntim)
  printVarSummary(eof_ts_cdata)

  delete(eof_ts_cdata!0)
  eof_ts_cdata!0	= "eof"
  eof_ts_cdata!1	= "time"
  eof_ts_cdata&time	= time

  print("==============")                                  
  printVarSummary(eof_ts_cdata)
  printMinMax(eof_ts_cdata, True)

;  print(eof_ts_cdata(1,0:1000))

  nvar	= 2
  ceof	= new((/nvar,neof,nlat,mlon/),typeof(cdata),getFillValue(cdata))

  do n=0,neof-1
     ceof(0,n,:,:)	= eof_cdata(n,:,0:mlon-1)
     ceof(1,n,:,:)	= eof_cdata(n,:,mlon:2*mlon-1)
  end do
  
  ceof!0	= "var"
  ceof!1	= "eof"
  ceof!2	= "lat"
  ceof!3	= "lon"
  ceof&lat	= olr&lat
  ceof&lon	= olr&lon

  ceof_ts		= new((/nvar,neof,ntim/),typeof(cdata),getFillValue(cdata))
  ceof_ts(0,:,:)	= eofunc_ts_Wrap(olr(lat|:,lon|:,time|:),ceof(0,:,:,:),False)
  ceof_ts(1,:,:)	= eofunc_ts_Wrap(u850(lat|:,lon|:,time|:),ceof(1,:,:,:),False)

  delete(ceof_ts&time) 
  ceof_ts!0	= "var"
;  ceof_ts!1	= "time"
  ceof_ts&time	= time

  printVarSummary(ceof)
  printVarSummary(ceof_ts)

;--------------------------------------------------------
;------------ Change the sign of EOFs -------------------
;--------------------------------------------------------
  imax_olr_eof1		= maxind(ceof(0,0,{0},:))
  imax_olr_eof2		= maxind(ceof(0,1,{0},:))
  imax_olr_eof3		= maxind(ceof(0,2,{0},:))
  imax_olr_eof4		= maxind(ceof(0,3,{15},:))
  lonmax_olr_eof1	= ceof&lon(imax_olr_eof1)
  lonmax_olr_eof2	= ceof&lon(imax_olr_eof2)
  lonmax_olr_eof3	= ceof&lon(imax_olr_eof3)
  lonmax_olr_eof4	= ceof&lon(imax_olr_eof4)

;---- Change the sign of EOF1, if OLR is positive over the tropical Indian Ocean
  if (lonmax_olr_eof1.gt.60.and.lonmax_olr_eof1.lt.120) then
     ceof(:,0,:,:)	= -ceof(:,0,:,:)
     ceof_ts(:,0,:)	= -ceof_ts(:,0,:)
     eof_cdata(0,:,:)	= -eof_cdata(0,:,:)
     eof_ts_cdata(0,:)	= -eof_ts_cdata(0,:)
  end if

;----- Change the sign of EOF2, if OLR is positive over the tropical western Pacific Ocean
  if (lonmax_olr_eof2.gt.90.and.lonmax_olr_eof2.lt.180) then
     ceof(:,1,:,:)	= -ceof(:,1,:,:)
     ceof_ts(:,1,:)	= -ceof_ts(:,1,:)
     eof_cdata(1,:,:)	= -eof_cdata(1,:,:)
     eof_ts_cdata(1,:)	= -eof_ts_cdata(1,:)
  end if

;---- Change the sign of EOF3, if OLR is positive over the tropical Indian Ocean
  if (lonmax_olr_eof3.gt.60.and.lonmax_olr_eof3.lt.120) then
     ceof(:,2,:,:)	= -ceof(:,2,:,:)
     ceof_ts(:,2,:)	= -ceof_ts(:,2,:)
     eof_cdata(2,:,:)	= -eof_cdata(2,:,:)
     eof_ts_cdata(2,:)	= -eof_ts_cdata(2,:)
  end if

;----- Change the sign of EOF4, if OLR is positive over the Indian Ocean
  if (lonmax_olr_eof4.ge.60.and.lonmax_olr_eof4.lt.120) then
     ceof(:,3,:,:)	= -ceof(:,3,:,:)
     ceof_ts(:,3,:)	= -ceof_ts(:,3,:)
     eof_cdata(3,:,:)	= -eof_cdata(3,:,:)
     eof_ts_cdata(3,:)	= -eof_ts_cdata(3,:)
  end if

;-------- write out cdata -----------
;  a=addfile("ERAI.eof_cdata.19860101-20161231.10S-40N.40E-160E.May-Oct.day.mean.nc","c")
;  a->eof_ts_cdata =eof_ts_cdata
;  a->ceof         =ceof

  wks = gsn_open_wks("ps","make.L1.2.ERAI.EOFs")
  plot = new(10,graphic)                

;;************************************************
;; Multivariate EOF plots
;;************************************************
                                      
  rts		= True
  rts@gsnDraw	= False       ; don't draw yet
  rts@gsnFrame	= False       ; don't advance frame yet
;  rts@gsnScale	= True        ; force text scaling               
  rts@cnFillOn	= True
  rts@cnLinesOn	= False

  rts@vpHeightF = 0.40        ; Changes the aspect ratio
  rts@vpWidthF  = 0.85
  rts@vpXF      = 0.10        ; change start locations
  rts@vpYF      = 0.75        ; the plot
;  rts@mpMinLatF= -10.
;  rts@mpMaxLatF= 40.
;  rts@mpMinLonF= 40.
;  rts@mpMaxLonF= 160.
;  rts@xyLineThicknesses	= (/ 2/)
;  rts@xyLineColors		= (/"black"/)
;  rts@gsnYRefLine		= 0.                  ; reference line   ;
  
  rts@cnLevelSelectionMode="ExplicitLevels"
  rts@cnLevels=(/-0.04,-0.03,-0.02,-0.01,-0.005,0.005,0.01,0.02,0.03,0.04/)

  rtsP                       = True                ; modify the panel plot
  rtsP@gsnMaximize           = True                ; large format
;  rtsP@txString              = "Multivariate EOF: 15S-15N:m"+yrStrt+"-"+yrLast 
 
;  rts@xyExplicitLegendLabels = (/"OLR", "U850" /)
  do n=0,neof-1
;  rts@xyExplicitLegendLabels = ""
    rts@gsnLeftString  = "EOF "+(n+1)
    rts@gsnRightString = sprintf("%3.1f",eof_cdata@pcvar(n))  +"%"
    plot(n)=gsn_csm_contour(wks,ceof(0,n,:,:),rts)
  end do
  gsn_panel(wks,plot(0:3),(/2,2/),rtsP)     ; now draw as one plot

  res=True
  do n=0,neof-1
    rts@gsnLeftString  = "EOF "+(n+1)
    rts@gsnRightString = sprintf("%3.1f",eof_cdata@pcvar(n))  +"%"
    plot(n+5)=gsn_csm_xy(wks,time(:),eof_ts_cdata(n,:),res)
  end do
  gsn_panel(wks,plot(5:8),(/2,2/),rtsP)     ; now draw as one plot
;plot(5)=gsn_csm_xy(wks,date,eof_ts_cdata(0,:),res)

end
