
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"

begin

 latS	= -10.
 latN	= 40.
 lonW	= 40.
 lonE	= 160.

;--------- Read in OLR, U850, and V850 -------------------
  f	= addfile ("ERAI.OLR.19860101-20161231.30S-60N.day.mean.nc", "r")
  olr	= f->OLR
  printVarSummary(olr)

 dims	= dimsizes(olr)
 ntim	= dims(0)
 nlat	= dims(1)
 nlon	= dims(2)

  f	= addfile ("ERAI.U850.19860101-20161231.30S-60N.day.mean.nc", "r")
  u850	= f->U850
 printVarSummary(u850)

  f	= addfile ("ERAI.V850.19860101-20161231.30S-60N.day.mean.nc", "r")
  v850	= f->V850
 printVarSummary(v850)

;------------- removing the slow annual cycle (mean and first three harmonics of climatological annual variation)
  time	= olr&time
  TIME	= cd_calendar(time,0)
  year	= toint(TIME(:,0))
  month	= toint(TIME(:,1))
  day	= toint(TIME(:,2))
  ddd	= day_of_year(year,month,day)
  yyyyddd= year*1000+ddd
 
  hclmday_olr	= clmDayTLL(olr,yyyyddd)
  hclmday_u850	= clmDayTLL(u850,yyyyddd)
  hclmday_v850	= clmDayTLL(v850,yyyyddd)
  printVarSummary(hclmday_u850)
  
  hclmday_sm_olr	= smthClmDayTLL(hclmday_olr,3)
  hclmday_sm_u850	= smthClmDayTLL(hclmday_u850,3)
  hclmday_sm_v850	= smthClmDayTLL(hclmday_v850,3)
  printVarSummary(hclmday_sm_u850)

  hanom_olr	= calcDayAnomTLL(olr,yyyyddd,hclmday_olr)
  hanom_u850	= calcDayAnomTLL(u850,yyyyddd,hclmday_u850)
  hanom_v850	= calcDayAnomTLL(v850,yyyyddd,hclmday_v850)
  printVarSummary(hanom_u850)

  hanom_sm_olr	= calcDayAnomTLL(olr,yyyyddd,hclmday_sm_olr)
  hanom_sm_u850	= calcDayAnomTLL(u850,yyyyddd,hclmday_sm_u850)
  hanom_sm_v850	= calcDayAnomTLL(v850,yyyyddd,hclmday_sm_v850)
  printVarSummary(hanom_sm_u850)

;--------------- removing the interannual variability by substacting the running mean of the last 120 days
 olr_new	= new((/ntim,nlat,nlon/),typeof(olr),getFillValue(hanom_sm_olr))
  do i = 0,119
     olr_new(i,:,:) = hanom_sm_olr(i,:,:)
  end do
  
  do i = 120,ntim-1
     n1			= i-120
     n2			= i-1
     olr_new(i,:,:)	= hanom_sm_olr(i,:,:)-dim_avg_n_Wrap(hanom_sm_olr(n1:n2,:,:),0)
  end do

  u850_new = new((/ntim,nlat,nlon/),typeof(u850),getFillValue(hanom_sm_u850))
  do i=0,119
     u850_new(i,:,:)	= hanom_sm_u850(i,:,:)
  end do
  
  do i=120,ntim-1
     n1			= i-120
     n2			= i-1
     u850_new(i,:,:)	= hanom_sm_u850(i,:,:)-dim_avg_n_Wrap(hanom_sm_u850(n1:n2,:,:),0)
  end do

  printVarSummary(u850_new)

  v850_new	= new((/ntim,nlat,nlon/),typeof(v850),getFillValue(hanom_sm_v850))
  do i=0,119
     v850_new(i,:,:)	= hanom_sm_v850(i,:,:)
  end do

  do i=120,ntim-1
     n1			= i-120
     n2			= i-1
     v850_new(i,:,:)	= hanom_sm_v850(i,:,:)-dim_avg_n_Wrap(hanom_sm_v850(n1:n2,:,:),0)
  end do

;----------- select summer data ---------------------
	TIME	= cd_calendar(time, 0)                          ; type float
	year	= floattointeger( TIME(:,0) )
	month	= floattointeger( TIME(:,1) )
	day	= floattointeger( TIME(:,2) )

	olr_new&time    = time
	u850_new&time   = time
	v850_new&time   = time

        season  = ind(month.ge.5.and.month.le.10)
	olr_s	= olr_new(season,:,:)
	u850_s	= u850_new(season,:,:)
	v850_s	= v850_new(season,:,:)
 printVarSummary(u850_s)

;------ write out data ------------
  	filo	= "ERAI.OLR_rmv.19860101-20161231.30S-60N.May-Oct.day.mean.nc"
	print("output file = "+filo)
	system("/bin/rm -f "+filo)      ; rm any pre-exist file, if any
	ncdf		= addfile(filo,"c")
  	ncdf->OLR_rmv	= olr_s
 
	filo	= "ERAI.U850_rmv.19860101-20161231.30S-60N.May-Oct.day.mean.nc"
	print("output file = "+filo)
	system("/bin/rm -f "+filo)      ; rm any pre-exist file, if any
	ncdf		= addfile(filo,"c")
	ncdf->U850_rmv	= u850_s

	filo	= "ERAI.V850_rmv.19860101-20161231.30S-60N.May-Oct.day.mean.nc"
	print("output file = "+filo)
	system("/bin/rm -f "+filo)      ; rm any pre-exist file, if any
	ncdf		= addfile(filo,"c")
	ncdf->V850_rmv	= v850_s

end
